aboutsummaryrefslogtreecommitdiffstats
path: root/lib/ssl/src/ssl_connection.erl
diff options
context:
space:
mode:
authorRaimo Niskanen <[email protected]>2019-02-08 11:41:27 +0100
committerRaimo Niskanen <[email protected]>2019-02-13 14:18:23 +0100
commit96cd83b6efed8ae8a1a0008e24885bae66c1834b (patch)
tree56097aece57096bf7fc9e0d485ecbe4a5e0b627b /lib/ssl/src/ssl_connection.erl
parent38ce21e37be4578a7a89856ddb91516279e58c13 (diff)
downloadotp-96cd83b6efed8ae8a1a0008e24885bae66c1834b.tar.gz
otp-96cd83b6efed8ae8a1a0008e24885bae66c1834b.tar.bz2
otp-96cd83b6efed8ae8a1a0008e24885bae66c1834b.zip
Use iovec() internally in send path
Diffstat (limited to 'lib/ssl/src/ssl_connection.erl')
-rw-r--r--lib/ssl/src/ssl_connection.erl6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/ssl/src/ssl_connection.erl b/lib/ssl/src/ssl_connection.erl
index 461f51dd3a..61524347eb 100644
--- a/lib/ssl/src/ssl_connection.erl
+++ b/lib/ssl/src/ssl_connection.erl
@@ -211,9 +211,9 @@ socket_control(dtls_connection = Connection, {_, Socket}, [Pid|_] = Pids, Transp
%%--------------------------------------------------------------------
send(Pid, Data) ->
call(Pid, {application_data,
- %% iolist_to_binary should really
- %% be called iodata_to_binary()
- erlang:iolist_to_binary(Data)}).
+ %% iolist_to_iovec should really
+ %% be called iodata_to_iovec()
+ erlang:iolist_to_iovec(Data)}).
%%--------------------------------------------------------------------
-spec recv(pid(), integer(), timeout()) ->